#![no_std]
#![no_main]

use embedded_hal::digital::v2::OutputPin;

use embedded_time::fixed_point::FixedPoint;

use panic_halt as _;

use rp_pico::Pins;
use rp_pico::entry;
use rp_pico::hal::{Clock, Sio, Watchdog, clocks::init_clocks_and_plls};
use rp_pico::pac::{CorePeripherals, Peripherals};

#[entry]
fn main() -> ! {
    let mut p = Peripherals::take().unwrap();
    let cp = CorePeripherals::take().unwrap();

    let mut watchdog = Watchdog::new(p.WATCHDOG);
    let clocks = init_clocks_and_plls(
        rp_pico::XOSC_CRYSTAL_FREQ,
        p.XOSC,
        p.CLOCKS,
        p.PLL_SYS,
        p.PLL_USB,
        &mut p.RESETS,
        &mut watchdog
    ).ok().unwrap();

    let sio = Sio::new(p.SIO);
    let pins = Pins::new(
        p.IO_BANK0,
        p.PADS_BANK0,
        sio.gpio_bank0,
        &mut p.RESETS,
    );

    let mut led = pins.led.into_push_pull_output();
    let mut delay = cortex_m::delay::Delay::new(cp.SYST, clocks.system_clock.freq().integer());

    loop {
        led.set_high().unwrap();
        delay.delay_ms(500);
        led.set_low().unwrap();
        delay.delay_ms(500);
    }
}
